
my_simple_jwt_auth

======

A simple jwt authenticaion module.

Installation
============

Fast install:

```
pip install my_simple_jwt_auth

```

Example
=======

    I have to update this.
   

Here is the output:
```
This should be updated.

```
    